local _G = _G
local AVR = AVR
local math_rad = math.rad
local math_cos = math.cos
local math_sin = math.sin
local math_deg = math.deg
local GetPlayerFacing = GetPlayerFacing
local unpack = unpack
local pairs = pairs
local UnitName = UnitName

-- Isolate the environment
local folder, core = ...
setfenv(1, core)
-- local

fireNovaRange = 10 --Fire Nova has a range of 10 yards.

scene = {} --Our AVR scene.

--~ local userName
local prev_OnEnable = core.OnEnable
function core:OnEnable()
	prev_OnEnable(self)
	AVR = _G.AVR
--~ 	userName = UnitName("player")
	if AVR then
		AddAVROptions()
		
		scene = AVR:GetTempScene(folder)
		scene:ClearScene()
		scene.visible = true
		
	end
end

local prev_OnDisable = core.OnDisable
function core:OnDisable()
	prev_OnDisable(self)
	
	for totemGUID in pairs(totemMeshes) do 
		RemoveTotemFromAVR(totemGUID)
	end
	scene:ClearScene()
	scene.visible = false
end
	
totemMeshes = {}
fireTotemRange = {}
function AddTotemToAVR(totemGUID, x, y, totemSlot, spellID, range, precise, caster)
	if AVR then
		if totemMeshes[totemGUID] then --it's already in our list? odd
			RemoveTotemFromAVR(totemGUID)
		end
		
		totemMeshes[totemGUID] = totemMeshes[totemGUID] or {}
		
		local bX, bY = GetAVRYardCoords(x, y)
		local range = range or totemInfo[spellID].range or 3
		
		local m
		
		local dottedLine = P.avrOtherDottedLine
		if userName == caster then
			dottedLine = false
		end
		
		local lines = Round(1.5*range+15) --10y = 30 parts, 30y = 60 parts.
		
		--[[ Main ring]]
		m = AVRCircleMesh:New(range, lines, dottedLine, P.AVRLineThickness * 32)
		m:TranslateMesh(bX, bY)
		m:SetColor(P.totemColour[totemSlot].r, P.totemColour[totemSlot].g, P.totemColour[totemSlot].b, 1)
		scene:AddMesh(m)
		totemMeshes[totemGUID].rangeRing = m
			
		--[[ Small texture under totem.]]
		if P.AVRTotemLocation == true then
			m = AVRFilledCircleMesh:New(1,6, false, nil)
			m:TranslateMesh(bX, bY)
			m:SetColor(P.totemColour[totemSlot].r, P.totemColour[totemSlot].g, P.totemColour[totemSlot].b, .2)
			scene:AddMesh(m)
			totemMeshes[totemGUID].smallCircle = m
		end
		
		--[[ Add a fire nova ring if it's a fire totem.]]
		if totemSlot == 1 and P.avrFireNovaRing == true then
			if precise == true then
				range = fireNovaRange --We know the exact location of the totem, set ring at 10 yards.
			else
				range = fireNovaRange - spawnDistance --Don't know the totem's location, set ring at 7 yards.
			end
			lines = Round(1.5*range+15)
			
			m = AVRCircleMesh:New(range, lines, dottedLine, P.AVRLineThickness * 32)
			m:TranslateMesh(bX, bY)
			m:SetColor(P.avrFireNovaColour.r, P.avrFireNovaColour.g, P.avrFireNovaColour.b, 1)
			scene:AddMesh(m)
			totemMeshes[totemGUID].firenovaRangeRing = m
			fireTotemRange[totemGUID] = range
		end
	end
end

function RemoveTotemFromAVR(totemGUID)
	if AVR and totemMeshes[totemGUID] then
		for name, mesh in pairs(totemMeshes[totemGUID]) do 
			mesh:Remove()
			mesh = nil
		end
		totemMeshes[totemGUID] = nil
	end
end


--------------------------------------------------
function GetAVRYardCoords(aX, aY)				--
-- AVR converts numbers differently then I do.	--
-- Thier X is the same, but Y is not. 			--
--------------------------------------------------
	local sX, sY = unpack(AVR.zoneData.currentScale)
	return aX*sX,(1-aY)*sY
end

